@@ -6,6 +6,9 @@ namespace Icinga\Application;
 require_once __DIR__ . '/EmbeddedWeb.php';
 
 use ErrorException;
+use ipl\I18n\GettextTranslator;
+use ipl\I18n\Locale;
+use ipl\I18n\StaticTranslator;
 use Zend_Controller_Action_HelperBroker;
 use Zend_Controller_Front;
 use Zend_Controller_Router_Route;
@@ -16,9 +19,7 @@ use Icinga\Authentication\Auth;
 use Icinga\User;
 use Icinga\Util\DirectoryIterator;
 use Icinga\Util\TimezoneDetect;
-use Icinga\Util\Translator;
 use Icinga\Web\Controller\Dispatcher;
-use Icinga\Web\Menu;
 use Icinga\Web\Navigation\Navigation;
 use Icinga\Web\Notification;
 use Icinga\Web\Session;
@@ -65,6 +66,9 @@ class Web extends EmbeddedWeb
      */
     private $user;
 
+    /** @var array */
+    protected $accessibleMenuItems;
+
     /**
      * Identify web bootstrap
      *
@@ -80,9 +84,9 @@ class Web extends EmbeddedWeb
     protected function bootstrap()
     {
         return $this
-            ->setupZendAutoloader()
             ->setupLogging()
             ->setupErrorHandling()
+            ->loadLibraries()
             ->loadConfig()
             ->setupLogger()
             ->setupRequest()
@@ -90,6 +94,7 @@ class Web extends EmbeddedWeb
             ->setupNotifications()
             ->setupResponse()
             ->setupZendMvc()
+            ->prepareInternationalization()
             ->setupModuleManager()
             ->loadSetupModuleIfNecessary()
             ->loadEnabledModules()
@@ -99,7 +104,8 @@ class Web extends EmbeddedWeb
             ->setupUser()
             ->setupTimezone()
             ->setupInternationalization()
-            ->setupFatalErrorHandling();
+            ->setupFatalErrorHandling()
+            ->registerApplicationHooks();
     }
 
     /**
@@ -241,7 +247,7 @@ class Web extends EmbeddedWeb
         if ($type === 'dashboard-pane') {
             $panes = array();
             foreach ($config as $dashletName => $dashletConfig) {
-                if ($this->hasAccessToSharedNavigationItem($dashletConfig)) {
+                if ($this->hasAccessToSharedNavigationItem($dashletConfig, $config)) {
                     // TODO: Throw ConfigurationError if pane or url is missing
                     $panes[$dashletConfig->pane][$dashletName] = $dashletConfig->url;
                 }
@@ -280,18 +286,6 @@ class Web extends EmbeddedWeb
         return $navigation;
     }
 
-    /**
-     * Return the app's menu
-     *
-     * @deprecated Instantiate the returned class directly instead of using this method.
-     *
-     * @return  Menu
-     */
-    public function getMenu()
-    {
-        return new Menu();
-    }
-
     /**
      * Dispatch public interface
      */
@@ -335,7 +329,7 @@ class Web extends EmbeddedWeb
             $this->getRequest()->setUser($user);
             $this->user = $user;
 
-            if ($user->can('application/stacktraces')) {
+            if ($user->can('user/application/stacktraces')) {
                 $displayExceptions = $this->user->getPreferences()->getValue(
                     'icingaweb',
                     'show_stacktraces'
@@ -492,9 +486,7 @@ class Web extends EmbeddedWeb
      *
      * Uses the preferred user language or the browser suggested language or our default.
      *
-     * @return  string                      Detected locale code
-     *
-     * @see     Translator::DEFAULT_LOCALE  For the the default locale code.
+     * @return string Detected locale code
      */
     protected function detectLocale()
     {
@@ -504,9 +496,14 @@ class Web extends EmbeddedWeb
         ) {
             return $locale;
         }
+
+        /** @var GettextTranslator $translator */
+        $translator = StaticTranslator::$instance;
+
         if (isset($_SERVER['HTTP_ACCEPT_LANGUAGE'])) {
-            return Translator::getPreferredLocaleCode($_SERVER['HTTP_ACCEPT_LANGUAGE']);
+            return (new Locale())->getPreferred($_SERVER['HTTP_ACCEPT_LANGUAGE'], $translator->listLocales());
         }
-        return Translator::DEFAULT_LOCALE;
+
+        return $translator->getDefaultLocale();
     }
 }
