@@ -17,6 +17,10 @@ class FilterEqualOrLessThan extends FilterExpression
 
     public function matches($row)
     {
+        if (! isset($row->{$this->column})) {
+            return false;
+        }
+
         return (string) $row->{$this->column} <= (string) $this->expression;
     }
 }
