@@ -4,6 +4,7 @@
 namespace Icinga\Web;
 
 use Icinga\Web\Form\Element\DateTimePicker;
+use ipl\I18n\Translation;
 use Zend_Config;
 use Zend_Form;
 use Zend_Form_Element;
@@ -12,7 +13,6 @@ use Icinga\Application\Icinga;
 use Icinga\Authentication\Auth;
 use Icinga\Exception\ProgrammingError;
 use Icinga\Security\SecurityException;
-use Icinga\Util\Translator;
 use Icinga\Web\Form\ErrorLabeller;
 use Icinga\Web\Form\Decorator\Autosubmit;
 use Icinga\Web\Form\Element\CsrfCounterMeasure;
@@ -27,6 +27,11 @@ use Icinga\Web\Form\Element\CsrfCounterMeasure;
  */
 class Form extends Zend_Form
 {
+    use Translation {
+        translate as i18nTranslate;
+        translatePlural as i18nTranslatePlural;
+    }
+
     /**
      * The suffix to append to a field's hidden default field name
      */
@@ -737,6 +742,7 @@ class Form extends Zend_Form
     /**
      * Get whether the form is an API target
      *
+     * @todo This should probably only return true if the request is also an api request
      * @return bool
      */
     public function getIsApiTarget()
@@ -1015,7 +1021,7 @@ class Form extends Zend_Form
      */
     public function ensureElementAccessibility(Zend_Form_Element $element)
     {
-        if ($element->isRequired() && strpos(strtolower($element->getType()), 'checkbox') === false) {
+        if ($element->isRequired()) {
             $element->setAttrib('aria-required', 'true'); // ARIA
             $element->setAttrib('required', ''); // HTML5
             if (($cue = $this->getRequiredCue()) !== null && ($label = $element->getDecorator('label')) !== false) {
@@ -1079,7 +1085,7 @@ class Form extends Zend_Form
                 return $this;
             }
             if ($this->getElement($this->tokenElementName) === null) {
-                $this->addElement(new CsrfCounterMeasure($this->tokenElementName));
+                $this->addElement('CsrfCounterMeasure', $this->tokenElementName);
             }
         }
         return $this;
@@ -1120,7 +1126,7 @@ class Form extends Zend_Form
      * @param   Zend_Form   $form
      * @param   array       $defaults
      */
-    protected function preserveDefaults(Zend_Form $form, array & $defaults)
+    protected function preserveDefaults(Zend_Form $form, array &$defaults)
     {
         foreach ($form->getElements() as $name => $element) {
             if ((array_key_exists($name, $defaults)
@@ -1157,19 +1163,18 @@ class Form extends Zend_Form
 
         $formData = $this->getRequestData();
         if ($this->getIsApiTarget()
+            // TODO: Very very bad, wasSent() must not be bypassed if it's only an api request but not an qpi target
             || $this->getRequest()->isApiRequest()
             || $this->getUidDisabled()
             || $this->wasSent($formData)
         ) {
-            if (($frameUpload = (bool) $request->getUrl()->shift('_frameUpload', false))) {
-                $this->getView()->layout()->setLayout('wrapped');
-            }
             $this->populate($formData); // Necessary to get isSubmitted() to work
             if (! $this->getSubmitLabel() || $this->isSubmitted()) {
                 if ($this->isValid($formData)
                     && (($this->onSuccess !== null && false !== call_user_func($this->onSuccess, $this))
                         || ($this->onSuccess === null && false !== $this->onSuccess()))
                 ) {
+                    // TODO: Still bad. An api target must not behave as one if it's not an api request
                     if ($this->getIsApiTarget() || $this->getRequest()->isApiRequest()) {
                         // API targets and API requests will never redirect but immediately respond w/ JSON-encoded
                         // notifications
@@ -1184,11 +1189,10 @@ class Form extends Zend_Form
                         $this->getResponse()->json()
                             ->setSuccessData($message !== null ? array('message' => $message) : null)
                             ->sendResponse();
-                    } elseif (! $frameUpload) {
-                        $this->getResponse()->redirectAndExit($this->getRedirectUrl());
                     } else {
-                        $this->getView()->layout()->redirectUrl = $this->getRedirectUrl()->getAbsoluteUrl();
+                        $this->getResponse()->redirectAndExit($this->getRedirectUrl());
                     }
+                // TODO: Still bad. An api target must not behave as one if it's not an api request
                 } elseif ($this->getIsApiTarget() || $this->getRequest()->isApiRequest()) {
                     $this->getResponse()->json()->setFailData($this->getMessages())->sendResponse();
                 }
@@ -1212,7 +1216,8 @@ class Form extends Zend_Form
      */
     public function isSubmitted()
     {
-        if (strtolower($this->getRequest()->getMethod()) !== $this->getMethod()) {
+        $requestMethod = $this->getRequest()->getMethod();
+        if (strtolower($requestMethod ?: '') !== $this->getMethod()) {
             return false;
         }
         if ($this->getIsApiTarget() || $this->getRequest()->isApiRequest()) {
@@ -1479,7 +1484,8 @@ class Form extends Zend_Form
      */
     protected function getRequestData()
     {
-        if (strtolower($this->request->getMethod()) === $this->getMethod()) {
+        $requestMethod = $this->getRequest()->getMethod();
+        if (strtolower($requestMethod ?: '') === $this->getMethod()) {
             return $this->request->{'get' . ($this->request->isPost() ? 'Post' : 'Query')}();
         }
 
@@ -1515,7 +1521,9 @@ class Form extends Zend_Form
      */
     protected function translate($text, $context = null)
     {
-        return Translator::translate($text, $this->getTranslationDomain(), $context);
+        $this->translationDomain = $this->getTranslationDomain();
+
+        return $this->i18nTranslate($text, $context);
     }
 
     /**
@@ -1530,13 +1538,9 @@ class Form extends Zend_Form
      */
     protected function translatePlural($textSingular, $textPlural, $number, $context = null)
     {
-        return Translator::translatePlural(
-            $textSingular,
-            $textPlural,
-            $number,
-            $this->getTranslationDomain(),
-            $context
-        );
+        $this->translationDomain = $this->getTranslationDomain();
+
+        return $this->i18nTranslatePlural($textSingular, $textPlural, $number, $context);
     }
 
     /**
