@@ -1,8 +1,10 @@
 <?php
-/* Icinga Web 2 | (c) 2013-2015 Icinga Development Team | GPLv2+ */
+/* Icinga Web 2 | (c) 2014 Icinga Development Team | GPLv2+ */
 
 namespace Icinga\Web;
 
+use Icinga\Forms\ConfigForm;
+use Icinga\Module\Setup\Forms\ModulePage;
 use LogicException;
 use InvalidArgumentException;
 use Icinga\Web\Session\SessionNamespace;
@@ -79,7 +81,6 @@ class Wizard
      */
     protected function init()
     {
-
     }
 
     /**
@@ -131,9 +132,9 @@ class Wizard
      *
      * Note that it's also possible to retrieve a nested wizard's page by using this method.
      *
-     * @param   string      $name   The name of the page to return
+     * @param   string                 $name    The name of the page to return
      *
-     * @return  null|Form           The page or null in case there is no page with the given name
+     * @return  ModulePage|Form|null            The page or null in case there is no page with the given name
      */
     public function getPage($name)
     {
@@ -154,7 +155,7 @@ class Wizard
     public function addPage($page)
     {
         if (! $page instanceof Form && ! $page instanceof self) {
-            throw InvalidArgumentException(
+            throw new InvalidArgumentException(
                 'The $page argument must be an instance of Icinga\Web\Form '
                 . 'or Icinga\Web\Wizard but is of type: ' . get_class($page)
             );
@@ -245,7 +246,6 @@ class Wizard
      */
     public function setupPage(Form $page, Request $request)
     {
-
     }
 
     /**
@@ -288,7 +288,7 @@ class Wizard
 
                 if ($isValid) {
                     $pageData = & $this->getPageData();
-                    $pageData[$page->getName()] = $page->getValues();
+                    $pageData[$page->getName()] = ConfigForm::transformEmptyValuesToNull($page->getValues());
                     $this->setCurrentPage($this->getNewPage($requestedPage, $page));
                     $page->getResponse()->redirectAndExit($page->getRedirectUrl());
                 }
@@ -430,8 +430,7 @@ class Wizard
             if (! $this->hasPageData($requestedPage) && ($index = array_search($page, $pages, true)) > 0) {
                 $previousPage = $pages[$index - 1];
                 if ($originPage === null || ($previousPage->getName() !== $originPage->getName()
-                    && array_search($originPage, $pages, true) < $index))
-                {
+                    && array_search($originPage, $pages, true) < $index)) {
                     $permitted = $this->hasPageData($previousPage->getName());
                 }
             }
@@ -608,7 +607,7 @@ class Wizard
                 'button',
                 static::BTN_NEXT,
                 array(
-                    'class'         => 'control-button',
+                    'class'         => 'control-button btn-primary',
                     'type'          => 'submit',
                     'value'         => $pages[1]->getName(),
                     'label'         => t('Next'),
@@ -632,7 +631,7 @@ class Wizard
                 'button',
                 static::BTN_NEXT,
                 array(
-                    'class'         => 'control-button',
+                    'class'         => 'control-button btn-primary',
                     'type'          => 'submit',
                     'value'         => $pages[$index + 1]->getName(),
                     'label'         => t('Next'),
@@ -656,7 +655,7 @@ class Wizard
                 'button',
                 static::BTN_NEXT,
                 array(
-                    'class'         => 'control-button',
+                    'class'         => 'control-button btn-primary',
                     'type'          => 'submit',
                     'value'         => $page->getName(),
                     'label'         => t('Finish'),
