@@ -3,23 +3,24 @@
 
 namespace Icinga\Module\Monitoring\Backend\Ido\Query;
 
+use Icinga\Data\Filter\Filter;
+use Icinga\Data\Filter\FilterExpression;
+
 /**
  * Query for host downtime end history records
  */
 class HostdowntimeendhistoryQuery extends HostdowntimestarthistoryQuery
 {
-    /**
-     * {@inheritdoc}
-     */
-    public function whereToSql($col, $sign, $expression)
+    protected function requireFilterColumns(Filter $filter)
     {
-        if ($col === 'UNIX_TIMESTAMP(hdh.actual_end_time)') {
-            return 'hdh.actual_end_time ' . $sign . ' ' . $this->timestampForSql(
-                $this->valueToTimestamp($expression)
-            );
-        } else {
-            return parent::whereToSql($col, $sign, $expression);
+        if ($filter instanceof FilterExpression && $filter->getColumn() === 'timestamp') {
+            $this->requireColumn('timestamp');
+            $filter->setColumn('hdh.actual_end_time');
+            $filter->setExpression($this->timestampForSql($this->valueToTimestamp($filter->getExpression())));
+            return null;
         }
+
+        return parent::requireFilterColumns($filter);
     }
 
     /**
@@ -28,7 +29,9 @@ class HostdowntimeendhistoryQuery extends HostdowntimestarthistoryQuery
     protected function joinBaseTables()
     {
         parent::joinBaseTables(true);
-        $this->select->where("hdh.actual_end_time > '1970-01-02 00:00:00'");
+        $this->select->where(
+            "hdh.actual_end_time > '1970-01-02 00:00:00' AND hdh.was_started = 1 AND hdh.was_cancelled = 0"
+        );
         $this->columnMap['downtimehistory']['type'] = "('dt_end')";
         $this->columnMap['downtimehistory']['timestamp'] = str_replace(
             'actual_start_time',
