@@ -102,7 +102,9 @@ class HostdowntimestarthistoryQuery extends IdoQuery
                 "hdh.actual_start_time > '1970-01-02 00:00:00'"
             );
         }
-
+        $this->select->where(
+            "hdh.was_started = 1 AND hdh.was_cancelled = 0"
+        );
         $this->joinedVirtualTables['downtimehistory'] = true;
     }
 
