@@ -40,7 +40,7 @@
         var $a = $(event.currentTarget);
         var url = $a.attr('href');
         var $modal = _this.$ghost.clone();
-        var $urlTarget = _this.icinga.loader.getLinkTargetFor($a, false);
+        var $redirectTarget = $a.closest('.container');
 
         _this.modalOpener = event.currentTarget;
 
@@ -50,8 +50,8 @@
         // Add showCompact, we don't want controls in a modal
         url = _this.icinga.utils.addUrlFlag(url, 'showCompact');
 
-        // Set the toggle's base target on the modal to use it as redirect target
-        $modal.data('redirectTarget', $urlTarget);
+        // Set the toggle's container to use it as redirect target
+        $modal.data('redirectTarget', $redirectTarget);
 
         // Final preparations, the id is required so that it's not `display:none` anymore
         $modal.attr('id', 'modal');
@@ -68,7 +68,7 @@
             if (req.status >= 500) {
                 // Yes, that's done twice (by us and by the base fail handler),
                 // but `renderContentToContainer` does too many useful things..
-                _this.icinga.loader.renderContentToContainer(req.responseText, $urlTarget, req.action);
+                _this.icinga.loader.renderContentToContainer(req.responseText, $redirectTarget, req.action);
             } else if (req.status > 0) {
                 var msg = $(req.responseText).find('.error-message').text();
                 if (msg && msg !== errorThrown) {
@@ -91,7 +91,7 @@
      * @param $autoSubmittedBy {jQuery} The element triggering the auto submit, if any
      * @returns {boolean}
      */
-    Modal.prototype.onFormSubmit = function(event, $autoSubmittedBy) {
+    Modal.prototype.onFormSubmit = function(event) {
         var _this = event.data.self;
         var $form = $(event.currentTarget).closest('form');
         var $modal = $form.closest('#modal');
@@ -105,9 +105,16 @@
             $form.removeData('submitButton');
         }
 
+        let $autoSubmittedBy;
+        if (! $autoSubmittedBy && event.detail && event.detail.submittedBy) {
+            $autoSubmittedBy = $(event.detail.submittedBy);
+        }
+
+        // Prevent our other JS from running
+        $modal[0].dataset.noIcingaAjax = '';
+
         var req = _this.icinga.loader.submitForm($form, $autoSubmittedBy, $button);
         req.addToHistory = false;
-        req.$redirectTarget = $modal.data('redirectTarget');
         req.done(function (data, textStatus, req) {
             var title = req.getResponseHeader('X-Icinga-Title');
             if (!! title) {
@@ -117,8 +124,14 @@
             if (req.getResponseHeader('X-Icinga-Redirect')) {
                 _this.hide($modal);
             }
+        }).always(function () {
+            delete $modal[0].dataset.noIcingaAjax;
         });
 
+        if (! ('baseTarget' in $form[0].dataset)) {
+            req.$redirectTarget = $modal.data('redirectTarget');
+        }
+
         if (typeof $autoSubmittedBy === 'undefined') {
             // otherwise the form is submitted several times by clicking the "Submit" button several times
             $form.find('input[type=submit],button[type=submit],button:not([type])').prop('disabled', true);
@@ -136,7 +149,17 @@
      * @returns {boolean}
      */
     Modal.prototype.onFormAutoSubmit = function(event) {
-        return event.data.self.onFormSubmit(event, $(event.currentTarget));
+        let form = event.currentTarget.form;
+        let modal = form.closest('#modal');
+
+        // Prevent our other JS from running
+        modal.dataset.noIcingaAjax = '';
+
+        form.dispatchEvent(new CustomEvent('submit', {
+            cancelable: true,
+            bubbles: true,
+            detail: { submittedBy: event.currentTarget }
+        }));
     };
 
     /**
