@@ -524,11 +524,11 @@
                 var originUrl = req.$target.data('icingaUrl');
 
                 $(window).on('popstate.__back__', { self: this }, function (event) {
-                    var _this = event.data.self;
-                    var $refreshTarget = $('#col2');
-                    var refreshUrl;
+                    const _this = event.data.self;
+                    let $refreshTarget = $('#col2');
+                    let refreshUrl;
 
-                    var hash = icinga.history.getCol2State();
+                    const hash = icinga.history.getCol2State();
                     if (hash && hash.match(/^#!/)) {
                         // TODO: These three lines are copied from history.js, I don't like this
                         var parts = hash.split(/#!/);
@@ -546,22 +546,10 @@
                         $refreshTarget = $('#col1');
                     }
 
-                    // loadUrl won't run this request, as due to the history handling it's already running.
-                    // The important bit though is that it returns this (already running) request. This way
-                    // it's possible to set `scripted = true` on the request. (`addToHistory = true` should
-                    // already be the case, though it's added again just in case it's not already `true`..)
-                    var req = _this.loadUrl(refreshUrl, $refreshTarget);
-                    req.addToHistory = false;
-                    req.scripted = true;
-
-                    setTimeout(function () {
-                        // TODO: Find a better solution than a hardcoded one
-                        // This is still the *cheat* to get live results
-                        // (in case there's a delay and a change is not instantly effective)
-                        var req = _this.loadUrl(refreshUrl, $refreshTarget);
-                        req.addToHistory = false;
-                        req.scripted = true;
-                    }, 1000);
+                    const refreshReq = _this.loadUrl(refreshUrl, $refreshTarget);
+                    refreshReq.autoRefreshInterval = req.getResponseHeader('X-Icinga-Refresh');
+                    refreshReq.autorefresh = true;
+                    refreshReq.scripted = true;
 
                     $(window).off('popstate.__back__');
                 });
@@ -649,6 +637,7 @@
                 var redirectionUrl = icinga.utils.addUrlFlag(url, 'renderLayout');
                 var r = this.loadUrl(redirectionUrl, $('#layout'));
                 r.historyUrl = url;
+                r.referrer = referrer;
                 if (parts.length) {
                     r.loadNext = parts;
                 } else if (!! document.location.hash) {
@@ -801,14 +790,9 @@
                 this.icinga.ui.setWindowId(windowId);
             }
 
-            var referrer = req.referrer;
-            if (typeof referrer === 'undefined') {
-                referrer = req;
-            }
-
             var autoSubmit = false;
             var currentUrl = this.icinga.utils.parseUrl(req.$target.data('icingaUrl'));
-            if (referrer.method === 'POST') {
+            if (req.method === 'POST') {
                 var newUrl = this.icinga.utils.parseUrl(req.url);
                 if (newUrl.path === currentUrl.path && this.icinga.utils.arraysEqual(newUrl.params, currentUrl.params)) {
                     autoSubmit = true;
@@ -828,7 +812,7 @@
                     let url = currentUrl.path + (locationQuery ? '?' + locationQuery : '');
                     if (req.autosubmit || autoSubmit) {
                         // Also update a form's action if it doesn't differ from the container's url
-                        var $form = $(referrer.forceFocus).closest('form');
+                        var $form = $(req.forceFocus).closest('form');
                         var formAction = $form.attr('action');
                         if (!! formAction) {
                             formAction = this.icinga.utils.parseUrl(formAction);
@@ -973,7 +957,7 @@
                 });
             }
 
-            if (this.processRedirectHeader(req)) {
+            if ((textStatus === 'abort' && typeof req.referrer !== 'undefined') || this.processRedirectHeader(req)) {
                 return;
             }
 
