@@ -210,6 +210,18 @@
             var kill = this.cutContainer($('#col1'));
             this.pasteContainer($('#col1'), col2);
             this.icinga.behaviors.navigation.trySetActiveAndSelectedByUrl($('#col1').data('icingaUrl'));
+            $('#col1').trigger('column-moved', 'col2');
+        },
+
+        moveToRight: function () {
+            let col1 = document.getElementById('col1'),
+                col2 = document.getElementById('col2'),
+                col1Backup = this.cutContainer($(col1));
+
+            this.cutContainer($(col2)); // Clear col2 states
+            this.pasteContainer($(col2), col1Backup);
+            this.layout2col();
+            $(col2).trigger('column-moved', 'col1');
         },
 
         cutContainer: function ($col) {
@@ -291,7 +303,7 @@
                     this.currentLayout = matched[1];
                     if (this.currentLayout === 'poor' || this.currentLayout === 'minimal') {
                         this.layout1col();
-                    } else {
+                    } else if (this.icinga.initialized) {
                         // layout1col() also triggers this, that's why an else is required
                         $('#layout').trigger('layout-change');
                     }
@@ -319,20 +331,27 @@
             this.icinga.logger.debug('Switching to single col');
             $('#layout').removeClass('twocols');
             this.closeContainer($('#col2'));
-            $('#layout').trigger('layout-change');
+
+            if (this.icinga.initialized) {
+                $('#layout').trigger('layout-change');
+            }
+
             // one-column layouts never have any selection active
             $('#col1').removeData('icinga-actiontable-former-href');
             this.icinga.behaviors.actiontable.clearAll();
         },
 
         closeContainer: function($c) {
+            this.icinga.loader.stopPendingRequestsFor($c);
             $c.removeData('icingaUrl');
             $c.removeData('icingaTitle');
             $c.removeData('icingaRefresh');
             $c.removeData('lastUpdate');
             $c.removeData('icingaModule');
-            this.icinga.loader.stopPendingRequestsFor($c);
+            delete $c[0].dataset.icingaContainerId;
+            $c.removeAttr('class').attr('class', 'container');
             $c.trigger('close-column');
+            this.icinga.history.pushCurrentState();
             $c.html('');
         },
 
@@ -340,7 +359,10 @@
             if (! this.isOneColLayout()) { return; }
             this.icinga.logger.debug('Switching to double col');
             $('#layout').addClass('twocols');
-            $('#layout').trigger('layout-change');
+
+            if (this.icinga.initialized) {
+                $('#layout').trigger('layout-change');
+            }
         },
 
         prepareColumnFor: function ($el, $target) {
@@ -471,8 +493,8 @@
                         ++minute;
                         second = 0;
                     }
-                    el.innerHTML = el.innerHTML.substr(0, partialTime.index) + minute.toString() + 'm '
-                        + second.toString() + 's' + el.innerHTML.substr(partialTime.index + partialTime[0].length);
+                    el.innerHTML = el.innerHTML.substring(0, partialTime.index) + minute.toString() + 'm '
+                        + second.toString() + 's' + el.innerHTML.substring(partialTime.index + partialTime[0].length);
                 }
             });
 
@@ -505,9 +527,17 @@
                         } else {
                             --second;
                         }
+
+                        if (minute === 0 && second === 0 && el.dataset.agoLabel) {
+                            el.innerText = el.dataset.agoLabel;
+                            el.classList.remove('time-until');
+                            el.classList.add('time-ago');
+
+                            return;
+                        }
                     }
-                    el.innerHTML = el.innerHTML.substr(0, partialTime.index) + invert + minute.toString() + 'm '
-                        + second.toString() + 's' + el.innerHTML.substr(partialTime.index + partialTime[0].length);
+                    el.innerHTML = el.innerHTML.substring(0, partialTime.index) + invert + minute.toString() + 'm '
+                        + second.toString() + 's' + el.innerHTML.substring(partialTime.index + partialTime[0].length);
                 }
             });
         },
